@@ -1,3 +1,5 @@
+import re
+
 from django.forms import (
     BaseForm,
     BaseFormSet,
@@ -31,7 +33,7 @@ from .forms import (
     render_label,
 )
 from .text import text_value
-from .utils import add_css_class, render_template_file
+from .utils import IS_PRE_DJANGO4, add_css_class, render_template_file
 
 try:
     # If Django is set up without a database, importing this widget gives RuntimeError
@@ -134,7 +136,7 @@ class FormsetRenderer(BaseRenderer):
         return ""
 
     def _render(self):
-        return "{}{}{}".format(self.render_errors(), self.render_management_form(), self.render_forms())
+        return f"{self.render_errors()}{self.render_management_form()}{self.render_forms()}"
 
 
 class FormRenderer(BaseRenderer):
@@ -311,18 +313,20 @@ class FieldRenderer(BaseRenderer):
 
     def list_to_class(self, html, klass):
         classes = add_css_class(klass, self.get_size_class())
-        mapping = [
-            ("<ul", "<div"),
-            ("</ul>", "</div>"),
-            ("<li", '<div class="{klass}"'.format(klass=classes)),
-            ("</li>", "</div>"),
-        ]
-        for k, v in mapping:
-            html = html.replace(k, v)
-        return html
+        if IS_PRE_DJANGO4:
+            return self._list_to_class_pre_django4(html, classes)
+        return re.sub("\s*<div>\s*<label", f' <div class="{classes}"><label', html)
+
+    def _list_to_class_pre_django4(self, html, classes):
+        return (
+            html.replace("<ul", "<div")
+            .replace("</ul>", "</div>")
+            .replace("<li", f'<div class="{classes}"')
+            .replace("</li>", "</div>")
+        )
 
     def put_inside_label(self, html):
-        content = "{field} {label}".format(field=html, label=self.label)
+        content = f"{html} {self.label}"
         return render_label(
             content=mark_safe(content),
             label_for=self.field.id_for_label,
@@ -352,13 +356,13 @@ class FieldRenderer(BaseRenderer):
         </div>
         """
         # TODO This needs improvement
-        return '<div class="row bootstrap3-multi-input"><div class="col-xs-12">{html}</div></div>'.format(html=html)
+        return f'<div class="row bootstrap3-multi-input"><div class="col-xs-12">{html}</div></div>'
 
     def post_widget_render(self, html):
-        if isinstance(self.widget, RadioSelect):
-            html = self.list_to_class(html, "radio")
-        elif isinstance(self.widget, CheckboxSelectMultiple):
+        if isinstance(self.widget, CheckboxSelectMultiple):
             html = self.list_to_class(html, "checkbox")
+        elif isinstance(self.widget, RadioSelect):
+            html = self.list_to_class(html, "radio")
         elif isinstance(self.widget, SelectDateWidget):
             html = self.fix_date_select_input(html)
         elif isinstance(self.widget, ClearableFileInput):
@@ -371,28 +375,16 @@ class FieldRenderer(BaseRenderer):
         if isinstance(self.widget, CheckboxInput):
             # Wrap checkboxes
             # Note checkboxes do not get size classes, see #318
-            html = '<div class="checkbox">{content}</div>'.format(content=html)
+            html = f'<div class="checkbox">{html}</div>'
         return html
 
     def make_input_group(self, html):
         if (self.addon_before or self.addon_after) and isinstance(
             self.widget, (TextInput, NumberInput, EmailInput, URLInput, DateInput, Select, PasswordInput)
         ):
-            before = (
-                '<span class="{input_class}">{addon}</span>'.format(
-                    input_class=self.addon_before_class, addon=self.addon_before
-                )
-                if self.addon_before
-                else ""
-            )
-            after = (
-                '<span class="{input_class}">{addon}</span>'.format(
-                    input_class=self.addon_after_class, addon=self.addon_after
-                )
-                if self.addon_after
-                else ""
-            )
-            html = '<div class="input-group">{before}{html}{after}</div>'.format(before=before, after=after, html=html)
+            before = f'<span class="{self.addon_before_class}">{self.addon_before}</span>' if self.addon_before else ""
+            after = f'<span class="{self.addon_after_class}">{self.addon_after}</span>' if self.addon_after else ""
+            html = f'<div class="input-group">{before}{html}{after}</div>'
         return html
 
     def append_to_field(self, html):
@@ -424,7 +416,7 @@ class FieldRenderer(BaseRenderer):
     def wrap_field(self, html):
         field_class = self.get_field_class()
         if field_class:
-            html = '<div class="{klass}">{html}</div>'.format(klass=field_class, html=html)
+            html = f'<div class="{field_class}">{html}</div>'
         return html
 
     def get_label_class(self):
