@@ -6,8 +6,15 @@ from django.test import TestCase
 
 from bootstrap3.exceptions import BootstrapError
 from bootstrap3.text import text_concat, text_value
-from bootstrap3.utils import add_css_class, render_tag, url_to_attrs_dict
+from bootstrap3.utils import (
+    IS_DJANGO5,
+    IS_PRE_DJANGO4,
+    add_css_class,
+    render_tag,
+    url_to_attrs_dict,
+)
 from tests.app.forms import (
+    RadioSetTestForm,
     SmallTestForm,
     TestForm,
     get_title_from_html,
@@ -44,7 +51,10 @@ class FormTest(TestCase):
     def test_field_addons(self):
         form = TestForm()
         res = render_form(form)
-        self.assertIn('<div class="input-group"><span class="input-group-addon">before</span><input', res)
+        self.assertIn(
+            '<div class="input-group"><span class="input-group-addon">before</span><input',
+            res,
+        )
         self.assertIn('><span class="input-group-addon">after</span></div>', res)
 
     def test_exclude(self):
@@ -77,7 +87,10 @@ class FormTest(TestCase):
         res = render_template_with_form("{% bootstrap_form form %}", {"form": form})
         self.assertIn("bootstrap3-err", res)
 
-        res = render_template_with_form('{% bootstrap_form form error_css_class="successful-test" %}', {"form": form})
+        res = render_template_with_form(
+            '{% bootstrap_form form error_css_class="successful-test" %}',
+            {"form": form},
+        )
         self.assertIn("successful-test", res)
 
         res = render_template_with_form('{% bootstrap_form form error_css_class="" %}', {"form": form})
@@ -89,7 +102,8 @@ class FormTest(TestCase):
         self.assertIn("bootstrap3-req", res)
 
         res = render_template_with_form(
-            '{% bootstrap_form form required_css_class="successful-test" %}', {"form": form}
+            '{% bootstrap_form form required_css_class="successful-test" %}',
+            {"form": form},
         )
         self.assertIn("successful-test", res)
 
@@ -102,7 +116,10 @@ class FormTest(TestCase):
         res = render_template_with_form("{% bootstrap_form form %}", {"form": form})
         self.assertIn("bootstrap3-bound", res)
 
-        res = render_template_with_form('{% bootstrap_form form bound_css_class="successful-test" %}', {"form": form})
+        res = render_template_with_form(
+            '{% bootstrap_form form bound_css_class="successful-test" %}',
+            {"form": form},
+        )
         self.assertIn("successful-test", res)
 
         res = render_template_with_form('{% bootstrap_form form bound_css_class="" %}', {"form": form})
@@ -153,6 +170,8 @@ class FieldTest(TestCase):
 
     def test_checkbox(self):
         res = render_form_field("cc_myself")
+        if IS_DJANGO5:
+            res = res.replace('aria-describedby="id_cc_myself_helptext"', "")
         self.assertHTMLEqual(
             """
 <div class="form-group">
@@ -423,13 +442,19 @@ class UtilsTest(TestCase):
     def test_render_tag(self):
         self.assertEqual(render_tag("span"), "<span></span>")
         self.assertEqual(render_tag("span", content="foo"), "<span>foo</span>")
-        self.assertEqual(render_tag("span", attrs={"bar": 123}, content="foo"), '<span bar="123">foo</span>')
+        self.assertEqual(
+            render_tag("span", attrs={"bar": 123}, content="foo"),
+            '<span bar="123">foo</span>',
+        )
 
     def test_url_to_attrs_dict(self):
         self.assertEqual(url_to_attrs_dict("my_link", "src"), {"src": "my_link"})
         self.assertEqual(url_to_attrs_dict({"url": "my_link"}, "src"), {"src": "my_link"})
         self.assertEqual(
-            url_to_attrs_dict({"url": "my_link", "crossorigin": "anonymous", "integrity": "super"}, "src"),
+            url_to_attrs_dict(
+                {"url": "my_link", "crossorigin": "anonymous", "integrity": "super"},
+                "src",
+            ),
             {"src": "my_link", "crossorigin": "anonymous", "integrity": "super"},
         )
         with self.assertRaises(BootstrapError):
@@ -456,7 +481,10 @@ class ShowLabelTest(TestCase):
     def test_for_formset(self):
         TestFormSet = formset_factory(TestForm, extra=1)
         test_formset = TestFormSet()
-        res = render_template_with_form("{% bootstrap_formset formset show_label=False %}", {"formset": test_formset})
+        res = render_template_with_form(
+            "{% bootstrap_formset formset show_label=False %}",
+            {"formset": test_formset},
+        )
         self.assertIn("sr-only", res)
 
     def test_button_with_icon(self):
@@ -495,14 +523,12 @@ class ShowAddonsTest(TestCase):
         addon_after = "af"
 
         res = render_template_with_form(
-            '{{% bootstrap_field form.{0} addon_before="{1}"  addon_after="{2}" %}}'.format(
-                field, addon_before, addon_after
-            )
+            f'{{% bootstrap_field form.{field} addon_before="{addon_before}"  addon_after="{addon_after}" %}}'
         )
 
         self.assertIn('class="input-group"', res)
-        self.assertIn('class="input-group-addon">{0}'.format(addon_before), res)
-        self.assertIn('class="input-group-addon">{0}'.format(addon_after), res)
+        self.assertIn(f'class="input-group-addon">{addon_before}', res)
+        self.assertIn(f'class="input-group-addon">{addon_after}', res)
 
     def test_show_addons_textinput(self):
         self.assertFieldHasAddons("subject")
@@ -521,3 +547,39 @@ class ShowAddonsTest(TestCase):
 
     def test_show_addons_url(self):
         self.assertFieldHasAddons("url")
+
+
+class InlineLayoutTestCase(TestCase):
+    def test_radioset_inline(self):
+        form = RadioSetTestForm()
+        res = render_template_with_form("{% bootstrap_form form layout='inline' %}", {"form": form})
+        expected = """
+            <div class="form-group bootstrap3-req">
+              <label class="sr-only">Radio</label>
+              <div id="id_radio">
+                <div class="radio">
+                  <label for="id_radio_0">
+                    <input type="radio" name="radio" value="1" class="" title="" required id="id_radio_0">
+                    Radio 1
+                  </label>
+                </div>
+                <div class="radio">
+                  <label for="id_radio_1">
+                    <input type="radio" name="radio" value="2" class="" title="" required id="id_radio_1">
+                    Radio 2
+                  </label>
+                </div>
+              </div>
+            </div>
+            """
+        if IS_PRE_DJANGO4:
+            expected = expected.replace(
+                '<label class="sr-only">Radio</label>',
+                '<label class="sr-only" for="id_radio_0">Radio</label>',
+            )
+        self.assertHTMLEqual(res, expected)
+        self.assertIn(
+            ' <div class="radio">',
+            res,
+            msg="Missing relevant whitespace for inline rendering.",
+        )
